==> jTSP-src-0.6.5.zip: jtsp/src/tsp/core/consumer/simple/TspSimpleSample.java <==
/* $Id: TspSimpleSample.java,v 1.1 2005/04/15 03:59:45 sgalles Exp $
 * -----------------------------------------------------------------------
 * 
 * TSP Library - core components for a generic Transport Sampling Protocol.
 * 
 * Copyright (c) 2002 Yves DUFRENNE, Stephane GALLES, Eric NOULARD and Robert PAGNOT 
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * -----------------------------------------------------------------------
 * 
 * Project    : TSP
 * SubProject : jTSP
 * Maintainer : tsp@astrium-space.com
 * Component  : Consumer
 * 
 * -----------------------------------------------------------------------
 * 
 * Purpose   : 
 * 
 * -----------------------------------------------------------------------
 */

package tsp.core.consumer.simple;

/**
 * The TSP Sample is the minimal
 * information stored by the {@link TspStreamReader}
 * when reading TSP sample on a TSP stream.
 */
public class TspSimpleSample {

	
        
	/**
	 * 
	 */
	public TspSimpleSample() {
		super();
	}
	/**
	 * @param index
	 * @param value
	 */
	public TspSimpleSample(int index, double value) {
		super();
		this.index = index;
		this.value = value;
	}
    /**
     * The provider global index.
     * (see TSP specs.).
     */
    private  int index;
    /**
     * The value of the sample
     */
    private  double value;
    
    
	/**
	 * @return Returns the index.
	 */
	public int getIndex() {
		return index;
	}
	/**
	 * @param index The index to set.
	 */
	public void setIndex(int index) {
		this.index = index;
	}
	/**
	 * @return Returns the value.
	 */
	public double getValue() {
		return value;
	}
	/**
	 * @param value The value to set.
	 */
	public void setValue(double value) {
		this.value = value;
	}
}

==> jTSP-src-0.8.0.zip: jtsp/src/tsp/core/consumer/simple/TspSimpleSample.java <==
/* $Id: TspSimpleSample.java,v 1.2 2005/10/05 00:11:47 sgalles Exp $
 * -----------------------------------------------------------------------
 * 
 * TSP Library - core components for a generic Transport Sampling Protocol.
 * 
 * Copyright (c) 2002 Yves DUFRENNE, Stephane GALLES, Eric NOULARD and Robert PAGNOT 
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * -----------------------------------------------------------------------
 * 
 * Project    : TSP
 * SubProject : jTSP
 * Maintainer : tsp@astrium-space.com
 * Component  : Consumer
 * 
 * -----------------------------------------------------------------------
 * 
 * Purpose   : 
 * 
 * -----------------------------------------------------------------------
 */

package tsp.core.consumer.simple;

/**
 * The TSP Sample is the minimal
 * information stored by the {@link TspStreamReader}
 * when reading TSP sample on a TSP stream.
 */
public class TspSimpleSample {

	
        
	/**
	 * 
	 */
	public TspSimpleSample() {
		super();
	}
	/**
	 * @param index
	 * @param value
	 */
	public TspSimpleSample(int index, double value) {
		super();
		this.index = index;
		this.value = value;
	}
    /**
     * The provider global index.
     * (see TSP specs.).
     */
    private  int index;
    /**
     * The value of the sample
     */
    private  double value;
    
    
	/**
	 * @return Returns the index.
	 */
	public int getIndex() {
		return index;
	}
	/**
	 * @param index The index to set.
	 */
	public void setIndex(int index) {
		this.index = index;
	}
	/**
	 * @return Returns the value.
	 */
	public double getValue() {
		return value;
	}
	/**
	 * @param value The value to set.
	 */
	public void setValue(double value) {
		this.value = value;
	}
	
	public void copy(final TspSimpleSample source){
		setIndex(source.getIndex());
		setValue(source.getValue());
	}
}
